#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_TWO_ADD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_TWO_ADD_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/two_add.hpp>

#endif
